@@ -113,8 +113,15 @@ class GDM2Theme(object):
 
     def SetWallpaper(self, WallpaperLocation, DoBlur):
         """ Sets the wallpaper and performs any mutations the user has requested. """
-        
-        image = Image.open(WallpaperLocation)
+
+        try:
+           image = Image.open(WallpaperLocation)
+        except:
+            # Something bad happened - usually a wrong filetype was passed
+            pass
+        return	
+
+			
         if DoBlur: 
             image.filter(ImageFilter.BLUR).save(self.XSPLASH_IMAGE)
         else:
